@@ -11,12 +11,12 @@ use fil_actors_runtime::{
     actor_error, make_map_with_root_and_bitwidth, wasm_trampoline, ActorDowncast, ActorError,
     Multimap, CRON_ACTOR_ADDR, INIT_ACTOR_ADDR, REWARD_ACTOR_ADDR, SYSTEM_ACTOR_ADDR,
 };
-use fvm_ipld_blockstore::Blockstore;
-use fvm_ipld_encoding::RawBytes;
 use fvm_shared::actor::builtin::{Type, CALLER_TYPES_SIGNABLE};
 use fvm_shared::address::Address;
 use fvm_shared::bigint::bigint_ser::{BigIntDe, BigIntSer};
+use fvm_shared::blockstore::Blockstore;
 use fvm_shared::econ::TokenAmount;
+use fvm_shared::encoding::RawBytes;
 use fvm_shared::error::ExitCode;
 use fvm_shared::reward::ThisEpochRewardReturn;
 use fvm_shared::sector::SealVerifyInfo;
@@ -43,8 +43,6 @@ mod types;
 /// This number is empirically determined
 const GAS_ON_SUBMIT_VERIFY_SEAL: i64 = 34721049;
 
-const ERR_TOO_MANY_PROVE_COMMITS: ExitCode = ExitCode::new(32);
-
 /// Storage power actor methods available
 #[derive(FromPrimitive)]
 #[repr(u64)]
@@ -74,10 +72,7 @@ impl Actor {
         rt.validate_immediate_caller_is(std::iter::once(&*SYSTEM_ACTOR_ADDR))?;
 
         let st = State::new(rt.store()).map_err(|e| {
-            e.downcast_default(
-                ExitCode::USR_ILLEGAL_STATE,
-                "Failed to create power actor state",
-            )
+            e.downcast_default(ExitCode::ErrIllegalState, "Failed to create power actor state")
         })?;
         rt.create(&st)?;
         Ok(())
@@ -105,10 +100,7 @@ impl Actor {
 
         let miner_actor_code_cid = rt.get_code_cid_for_type(Type::Miner);
 
-        let ext::init::ExecReturn {
-            id_address,
-            robust_address,
-        } = rt
+        let ext::init::ExecReturn { id_address, robust_address } = rt
             .send(
                 *INIT_ACTOR_ADDR,
                 ext::init::EXEC_METHOD,
@@ -124,7 +116,7 @@ impl Actor {
         rt.transaction(|st: &mut State, rt| {
             let mut claims =
                 make_map_with_root_and_bitwidth(&st.claims, rt.store(), HAMT_BIT_WIDTH).map_err(
-                    |e| e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to load claims"),
+                    |e| e.downcast_default(ExitCode::ErrIllegalState, "failed to load claims"),
                 )?;
             set_claim(
                 &mut claims,
@@ -137,31 +129,27 @@ impl Actor {
             )
             .map_err(|e| {
                 e.downcast_default(
-                    ExitCode::USR_ILLEGAL_STATE,
+                    ExitCode::ErrIllegalState,
                     "failed to put power in claimed table while creating miner",
                 )
             })?;
             st.miner_count += 1;
 
-            st.update_stats_for_new_miner(window_post_proof_type)
-                .map_err(|e| {
-                    actor_error!(
-                        USR_ILLEGAL_STATE,
-                        "failed to update power stats for new miner {}: {}",
-                        &id_address,
-                        e
-                    )
-                })?;
+            st.update_stats_for_new_miner(window_post_proof_type).map_err(|e| {
+                actor_error!(
+                    ErrIllegalState,
+                    "failed to update power stats for new miner {}: {}",
+                    &id_address,
+                    e
+                )
+            })?;
 
             st.claims = claims.flush().map_err(|e| {
-                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to flush claims")
+                e.downcast_default(ExitCode::ErrIllegalState, "failed to flush claims")
             })?;
             Ok(())
         })?;
-        Ok(CreateMinerReturn {
-            id_address,
-            robust_address,
-        })
+        Ok(CreateMinerReturn { id_address, robust_address })
     }
 
     /// Adds or removes claimed power for the calling actor.
@@ -180,7 +168,7 @@ impl Actor {
         rt.transaction(|st: &mut State, rt| {
             let mut claims =
                 make_map_with_root_and_bitwidth(&st.claims, rt.store(), HAMT_BIT_WIDTH).map_err(
-                    |e| e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to load claims"),
+                    |e| e.downcast_default(ExitCode::ErrIllegalState, "failed to load claims"),
                 )?;
 
             st.add_to_claim(
@@ -191,7 +179,7 @@ impl Actor {
             )
             .map_err(|e| {
                 e.downcast_default(
-                    ExitCode::USR_ILLEGAL_STATE,
+                    ExitCode::ErrIllegalState,
                     format!(
                         "failed to update power raw {}, qa {}",
                         params.raw_byte_delta, params.quality_adjusted_delta,
@@ -200,7 +188,7 @@ impl Actor {
             })?;
 
             st.claims = claims.flush().map_err(|e| {
-                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to flush claims")
+                e.downcast_default(ExitCode::ErrIllegalState, "failed to flush claims")
             })?;
             Ok(())
         })
@@ -223,7 +211,7 @@ impl Actor {
         // Ensure it is not possible to enter a large negative number which would cause
         // problems in cron processing.
         if params.event_epoch < 0 {
-            return Err(actor_error!(USR_ILLEGAL_ARGUMENT;
+            return Err(actor_error!(ErrIllegalArgument;
                 "cron event epoch {} cannot be less than zero", params.event_epoch));
         }
 
@@ -235,16 +223,15 @@ impl Actor {
                 CRON_QUEUE_AMT_BITWIDTH,
             )
             .map_err(|e| {
-                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to load cron events")
+                e.downcast_default(ExitCode::ErrIllegalState, "failed to load cron events")
             })?;
 
-            st.append_cron_event(&mut events, params.event_epoch, miner_event)
-                .map_err(|e| {
-                    e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to enroll cron event")
-                })?;
+            st.append_cron_event(&mut events, params.event_epoch, miner_event).map_err(|e| {
+                e.downcast_default(ExitCode::ErrIllegalState, "failed to enroll cron event")
+            })?;
 
             st.cron_event_queue = events.root().map_err(|e| {
-                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to flush cron events")
+                e.downcast_default(ExitCode::ErrIllegalState, "failed to flush cron events")
             })?;
             Ok(())
         })?;
@@ -281,9 +268,7 @@ impl Actor {
             // Can assume delta is one since cron is invoked every epoch.
             st.update_smoothed_estimate(1);
 
-            Ok(RawBytes::serialize(&BigIntSer(
-                &st.this_epoch_raw_byte_power,
-            )))
+            Ok(RawBytes::serialize(&BigIntSer(&st.this_epoch_raw_byte_power)))
         })?;
 
         // Update network KPA in reward actor
@@ -309,7 +294,7 @@ impl Actor {
             st.add_pledge_total(pledge_delta);
             if st.total_pledge_collateral.is_negative() {
                 return Err(actor_error!(
-                    USR_ILLEGAL_STATE,
+                    ErrIllegalState,
                     "negative total pledge collateral {}",
                     st.total_pledge_collateral
                 ));
@@ -340,52 +325,35 @@ impl Actor {
                 )
                 .map_err(|e| {
                     e.downcast_default(
-                        ExitCode::USR_ILLEGAL_STATE,
+                        ExitCode::ErrIllegalState,
                         "failed to load proof batching set",
                     )
                 })?
             } else {
                 debug!("ProofValidationBatch created");
-                Multimap::new(
-                    rt.store(),
-                    HAMT_BIT_WIDTH,
-                    PROOF_VALIDATION_BATCH_AMT_BITWIDTH,
-                )
+                Multimap::new(rt.store(), HAMT_BIT_WIDTH, PROOF_VALIDATION_BATCH_AMT_BITWIDTH)
             };
             let miner_addr = rt.message().caller();
-            let arr = mmap
-                .get::<SealVerifyInfo>(&miner_addr.to_bytes())
-                .map_err(|e| {
-                    e.downcast_default(
-                        ExitCode::USR_ILLEGAL_STATE,
-                        format!("failed to get seal verify infos at addr {}", miner_addr),
-                    )
-                })?;
+            let arr = mmap.get::<SealVerifyInfo>(&miner_addr.to_bytes()).map_err(|e| {
+                e.downcast_default(
+                    ExitCode::ErrIllegalState,
+                    format!("failed to get seal verify infos at addr {}", miner_addr),
+                )
+            })?;
             if let Some(arr) = arr {
                 if arr.count() >= MAX_MINER_PROVE_COMMITS_PER_EPOCH {
-                    return Err(ActorError::new(
-                        ERR_TOO_MANY_PROVE_COMMITS,
-                        format!(
-                            "miner {} attempting to prove commit over {} sectors in epoch",
-                            miner_addr, MAX_MINER_PROVE_COMMITS_PER_EPOCH
-                        ),
-                    ));
+                    return Err(actor_error!(ErrTooManyProveCommits;
+                        "miner {} attempting to prove commit over {} sectors in epoch",
+                        miner_addr, MAX_MINER_PROVE_COMMITS_PER_EPOCH));
                 }
             }
 
-            mmap.add(miner_addr.to_bytes().into(), seal_info)
-                .map_err(|e| {
-                    e.downcast_default(
-                        ExitCode::USR_ILLEGAL_STATE,
-                        "failed to insert proof into set",
-                    )
-                })?;
+            mmap.add(miner_addr.to_bytes().into(), seal_info).map_err(|e| {
+                e.downcast_default(ExitCode::ErrIllegalState, "failed to insert proof into set")
+            })?;
 
             let mmrc = mmap.root().map_err(|e| {
-                e.downcast_default(
-                    ExitCode::USR_ILLEGAL_STATE,
-                    "failed to flush proofs batch map",
-                )
+                e.downcast_default(ExitCode::ErrIllegalState, "failed to flush proofs batch map")
             })?;
 
             rt.charge_gas("OnSubmitVerifySeal", GAS_ON_SUBMIT_VERIFY_SEAL);
@@ -504,18 +472,14 @@ impl Actor {
                 result
             })
             .map_err(|e| {
-                format!(
-                    "failed to do transaction in process batch proof verifies: {}",
-                    e
-                )
+                format!("failed to do transaction in process batch proof verifies: {}", e)
             })?;
         if let Some(st_err) = st_err {
             return Err(st_err);
         }
 
-        let res = rt
-            .batch_verify_seals(&infos)
-            .map_err(|e| format!("failed to batch verify: {}", e))?;
+        let res =
+            rt.batch_verify_seals(&infos).map_err(|e| format!("failed to batch verify: {}", e))?;
 
         let mut res_iter = infos.iter().zip(res.iter().copied());
         for (m, count) in miners {
@@ -550,10 +514,7 @@ impl Actor {
                 .map_err(|e| format!("failed to serialize ConfirmSectorProofsParams: {}", e))?,
                 Default::default(),
             ) {
-                error!(
-                    "failed to confirm sector proof validity to {}, error code {}",
-                    m, e
-                );
+                error!("failed to confirm sector proof validity to {}, error code {}", m, e);
             }
         }
         Ok(())
@@ -578,18 +539,18 @@ impl Actor {
                 CRON_QUEUE_AMT_BITWIDTH,
             )
             .map_err(|e| {
-                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to load cron events")
+                e.downcast_default(ExitCode::ErrIllegalState, "failed to load cron events")
             })?;
 
             let claims =
                 make_map_with_root_and_bitwidth::<_, Claim>(&st.claims, rt.store(), HAMT_BIT_WIDTH)
                     .map_err(|e| {
-                        e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to load claims")
+                        e.downcast_default(ExitCode::ErrIllegalState, "failed to load claims")
                     })?;
             for epoch in st.first_cron_epoch..=rt_epoch {
                 let epoch_events = load_cron_events(&events, epoch).map_err(|e| {
                     e.downcast_default(
-                        ExitCode::USR_ILLEGAL_STATE,
+                        ExitCode::ErrIllegalState,
                         format!("failed to load cron events at {}", epoch),
                     )
                 })?;
@@ -600,14 +561,9 @@ impl Actor {
 
                 for evt in epoch_events.into_iter() {
                     let miner_has_claim =
-                        claims
-                            .contains_key(&evt.miner_addr.to_bytes())
-                            .map_err(|e| {
-                                e.downcast_default(
-                                    ExitCode::USR_ILLEGAL_STATE,
-                                    "failed to look up claim",
-                                )
-                            })?;
+                        claims.contains_key(&evt.miner_addr.to_bytes()).map_err(|e| {
+                            e.downcast_default(ExitCode::ErrIllegalState, "failed to look up claim")
+                        })?;
                     if !miner_has_claim {
                         debug!("skipping cron event for unknown miner: {}", evt.miner_addr);
                         continue;
@@ -617,7 +573,7 @@ impl Actor {
 
                 events.remove_all(&epoch_key(epoch)).map_err(|e| {
                     e.downcast_default(
-                        ExitCode::USR_ILLEGAL_STATE,
+                        ExitCode::ErrIllegalState,
                         format!("failed to clear cron events at {}", epoch),
                     )
                 })?;
@@ -625,7 +581,7 @@ impl Actor {
 
             st.first_cron_epoch = rt_epoch + 1;
             st.cron_event_queue = events.root().map_err(|e| {
-                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to flush events")
+                e.downcast_default(ExitCode::ErrIllegalState, "failed to flush events")
             })?;
 
             Ok(())
@@ -649,10 +605,7 @@ impl Actor {
             // Failures are unexpected here but will result in removal of miner power
             // A log message would really help here.
             if let Err(e) = res {
-                error!(
-                    "OnDeferredCronEvent failed for miner {}: res {}",
-                    event.miner_addr, e
-                );
+                error!("OnDeferredCronEvent failed for miner {}: res {}", event.miner_addr, e);
                 failed_miner_crons.push(event.miner_addr)
             }
         }
@@ -662,7 +615,7 @@ impl Actor {
                 let mut claims =
                     make_map_with_root_and_bitwidth(&st.claims, rt.store(), HAMT_BIT_WIDTH)
                         .map_err(|e| {
-                            e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to load claims")
+                            e.downcast_default(ExitCode::ErrIllegalState, "failed to load claims")
                         })?;
 
                 // Remove power and leave miner frozen
@@ -679,7 +632,7 @@ impl Actor {
                 }
 
                 st.claims = claims.flush().map_err(|e| {
-                    e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to flush claims")
+                    e.downcast_default(ExitCode::ErrIllegalState, "failed to flush claims")
                 })?;
                 Ok(())
             })?;
@@ -732,7 +685,7 @@ impl ActorCode for Actor {
                 let res = Self::current_total_power(rt)?;
                 Ok(RawBytes::serialize(res)?)
             }
-            None => Err(actor_error!(SYS_INVALID_METHOD; "Invalid method")),
+            None => Err(actor_error!(SysErrInvalidMethod; "Invalid method")),
         }
     }
 }
